@@ -1,8 +1,5 @@
 // This file is part of the uutils coreutils package.
 //
-// (c) Vsevolod Velichko <torkvemada@sorokdva.net>
-// (c) Jian Zeng <anonymousknight96 AT gmail.com>
-//
 // For the full copyright and license information, please view the LICENSE
 // file that was distributed with this source code.
 
@@ -10,7 +7,7 @@
 mod error;
 
 use crate::error::ChrootError;
-use clap::{crate_version, Arg, Command};
+use clap::{crate_version, Arg, ArgAction, Command};
 use std::ffi::CString;
 use std::io::Error;
 use std::os::unix::prelude::OsStrExt;
@@ -19,10 +16,10 @@ use std::process;
 use uucore::error::{set_exit_code, UClapError, UResult, UUsageError};
 use uucore::fs::{canonicalize, MissingHandling, ResolveMode};
 use uucore::libc::{self, chroot, setgid, setgroups, setuid};
-use uucore::{entries, format_usage};
+use uucore::{entries, format_usage, help_about, help_usage};
 
-static ABOUT: &str = "Run COMMAND with root directory set to NEWROOT.";
-static USAGE: &str = "{} [OPTION]... NEWROOT [COMMAND [ARG]...]";
+static ABOUT: &str = help_about!("chroot.md");
+static USAGE: &str = help_usage!("chroot.md");
 
 mod options {
     pub const NEWROOT: &str = "newroot";
@@ -49,7 +46,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
         None => return Err(ChrootError::MissingNewRoot.into()),
     };
 
-    let skip_chdir = matches.contains_id(options::SKIP_CHDIR);
+    let skip_chdir = matches.get_flag(options::SKIP_CHDIR);
     // We are resolving the path in case it is a symlink or /. or /../
     if skip_chdir
         && canonicalize(newroot, MissingHandling::Normal, ResolveMode::Logical)
@@ -116,7 +113,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     Ok(())
 }
 
-pub fn uu_app<'a>() -> Command<'a> {
+pub fn uu_app() -> Command {
     Command::new(uucore::util_name())
         .version(crate_version!())
         .about(ABOUT)
@@ -168,13 +165,14 @@ pub fn uu_app<'a>() -> Command<'a> {
                     "Use this option to not change the working directory \
                     to / after changing the root directory to newroot, \
                     i.e., inside the chroot.",
-                ),
+                )
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(options::COMMAND)
+                .action(ArgAction::Append)
                 .value_hint(clap::ValueHint::CommandName)
                 .hide(true)
-                .multiple_occurrences(true)
                 .index(2),
         )
 }
