@@ -62,15 +62,9 @@ impl CsplitOptions {
             split_name: crash_if_err!(
                 1,
                 SplitName::new(
-                    matches
-                        .get_one::<String>(options::PREFIX)
-                        .map(|s| s.to_owned()),
-                    matches
-                        .get_one::<String>(options::SUFFIX_FORMAT)
-                        .map(|s| s.to_owned()),
-                    matches
-                        .get_one::<String>(options::DIGITS)
-                        .map(|s| s.to_owned())
+                    matches.get_one::<String>(options::PREFIX).cloned(),
+                    matches.get_one::<String>(options::SUFFIX_FORMAT).cloned(),
+                    matches.get_one::<String>(options::DIGITS).cloned()
                 )
             ),
             keep_files,
