@@ -1,10 +1,7 @@
 // This file is part of the uutils coreutils package.
 //
-// (c) Fangxu Hu <framlog@gmail.com>
-// (c) Sylvestre Ledru <sylvestre@debian.org>
-//
-// For the full copyright and license information, please view the LICENSE file
-// that was distributed with this source code.
+// For the full copyright and license information, please view the LICENSE
+// file that was distributed with this source code.
 // spell-checker:ignore itotal iused iavail ipcent pcent tmpfs squashfs lofs
 mod blocks;
 mod columns;
@@ -746,7 +743,7 @@ mod tests {
 
         #[test]
         fn test_remote_included() {
-            let opt = Default::default();
+            let opt = Options::default();
             let m = mount_info("ext4", "/mnt/foo", true, false);
             assert!(is_included(&m, &opt));
         }
@@ -773,7 +770,7 @@ mod tests {
 
         #[test]
         fn test_dummy_excluded() {
-            let opt = Default::default();
+            let opt = Options::default();
             let m = mount_info("ext4", "/mnt/foo", false, true);
             assert!(!is_included(&m, &opt));
         }
@@ -864,11 +861,11 @@ mod tests {
 
     mod filter_mount_list {
 
-        use crate::filter_mount_list;
+        use crate::{filter_mount_list, Options};
 
         #[test]
         fn test_empty() {
-            let opt = Default::default();
+            let opt = Options::default();
             let mount_infos = vec![];
             assert!(filter_mount_list(mount_infos, &opt).is_empty());
         }
