@@ -803,8 +803,7 @@ fn digest_reader<T: Read>(
         Ok(digest.result_str())
     } else {
         // Assume it's SHAKE.  result_str() doesn't work with shake (as of 8/30/2016)
-        let mut bytes = Vec::new();
-        bytes.resize((output_bits + 7) / 8, 0);
+        let mut bytes = vec![0; (output_bits + 7) / 8];
         digest.hash_finalize(&mut bytes);
         Ok(encode(bytes))
     }
