@@ -195,7 +195,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     }
 
     let files: Vec<String> = match matches.get_many::<String>(options::FILE) {
-        Some(v) => v.clone().map(|v| v.to_owned()).collect(),
+        Some(v) => v.cloned().collect(),
         None => vec!["-".to_owned()],
     };
 
