@@ -211,9 +211,7 @@ fn parse_options(args: &ArgMatches) -> Result<NumfmtOptions> {
         _ => unreachable!("Should be restricted by clap"),
     };
 
-    let suffix = args
-        .get_one::<String>(options::SUFFIX)
-        .map(|s| s.to_owned());
+    let suffix = args.get_one::<String>(options::SUFFIX).cloned();
 
     let invalid =
         InvalidModes::from_str(args.get_one::<String>(options::INVALID).unwrap()).unwrap();
