@@ -1,31 +1,30 @@
-//  * This file is part of the uutils coreutils package.
-//  *
-//  * (c) 2014 Vsevolod Velichko <torkvemada@sorokdva.net>
-//  *
-//  * For the full copyright and license information, please view the LICENSE
-//  * file that was distributed with this source code.
+// This file is part of the uutils coreutils package.
+//
+// For the full copyright and license information, please view the LICENSE
+// file that was distributed with this source code.
 
 // spell-checker:ignore (ToDO) retcode
 
-#[macro_use]
-extern crate uucore;
-
-use clap::{builder::NonEmptyStringValueParser, crate_version, Arg, ArgMatches, Command};
+use clap::{
+    builder::NonEmptyStringValueParser, crate_version, Arg, ArgAction, ArgMatches, Command,
+};
 use std::{
     io::{stdout, Write},
     path::{Path, PathBuf},
 };
-use uucore::error::UClapError;
 use uucore::fs::make_path_relative_to;
 use uucore::{
     display::{print_verbatim, Quotable},
     error::{FromIo, UResult},
     format_usage,
     fs::{canonicalize, MissingHandling, ResolveMode},
+    help_about, help_usage,
+    line_ending::LineEnding,
 };
+use uucore::{error::UClapError, show, show_if_err};
 
-static ABOUT: &str = "print the resolved path";
-const USAGE: &str = "{} [OPTION]... FILE...";
+static ABOUT: &str = help_about!("realpath.md");
+const USAGE: &str = help_usage!("realpath.md");
 
 static OPT_QUIET: &str = "quiet";
 static OPT_STRIP: &str = "strip";
@@ -51,13 +50,13 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
         .map(PathBuf::from)
         .collect();
 
-    let strip = matches.contains_id(OPT_STRIP);
-    let zero = matches.contains_id(OPT_ZERO);
-    let quiet = matches.contains_id(OPT_QUIET);
-    let logical = matches.contains_id(OPT_LOGICAL);
-    let can_mode = if matches.contains_id(OPT_CANONICALIZE_EXISTING) {
+    let strip = matches.get_flag(OPT_STRIP);
+    let line_ending = LineEnding::from_zero_flag(matches.get_flag(OPT_ZERO));
+    let quiet = matches.get_flag(OPT_QUIET);
+    let logical = matches.get_flag(OPT_LOGICAL);
+    let can_mode = if matches.get_flag(OPT_CANONICALIZE_EXISTING) {
         MissingHandling::Existing
-    } else if matches.contains_id(OPT_CANONICALIZE_MISSING) {
+    } else if matches.get_flag(OPT_CANONICALIZE_MISSING) {
         MissingHandling::Missing
     } else {
         MissingHandling::Normal
@@ -73,7 +72,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     for path in &paths {
         let result = resolve_path(
             path,
-            zero,
+            line_ending,
             resolve_mode,
             can_mode,
             relative_to.as_deref(),
@@ -89,7 +88,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     Ok(())
 }
 
-pub fn uu_app<'a>() -> Command<'a> {
+pub fn uu_app() -> Command {
     Command::new(uucore::util_name())
         .version(crate_version!())
         .about(ABOUT)
@@ -99,33 +98,38 @@ pub fn uu_app<'a>() -> Command<'a> {
             Arg::new(OPT_QUIET)
                 .short('q')
                 .long(OPT_QUIET)
-                .help("Do not print warnings for invalid paths"),
+                .help("Do not print warnings for invalid paths")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_STRIP)
                 .short('s')
                 .long(OPT_STRIP)
                 .visible_alias("no-symlinks")
-                .help("Only strip '.' and '..' components, but don't resolve symbolic links"),
+                .help("Only strip '.' and '..' components, but don't resolve symbolic links")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_ZERO)
                 .short('z')
                 .long(OPT_ZERO)
-                .help("Separate output filenames with \\0 rather than newline"),
+                .help("Separate output filenames with \\0 rather than newline")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_LOGICAL)
                 .short('L')
                 .long(OPT_LOGICAL)
-                .help("resolve '..' components before symlinks"),
+                .help("resolve '..' components before symlinks")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_PHYSICAL)
                 .short('P')
                 .long(OPT_PHYSICAL)
-                .overrides_with_all(&[OPT_STRIP, OPT_LOGICAL])
-                .help("resolve symlinks as encountered (default)"),
+                .overrides_with_all([OPT_STRIP, OPT_LOGICAL])
+                .help("resolve symlinks as encountered (default)")
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_CANONICALIZE_EXISTING)
@@ -134,7 +138,8 @@ pub fn uu_app<'a>() -> Command<'a> {
                 .help(
                     "canonicalize by following every symlink in every component of the \
                      given name recursively, all components must exist",
-                ),
+                )
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_CANONICALIZE_MISSING)
@@ -143,12 +148,12 @@ pub fn uu_app<'a>() -> Command<'a> {
                 .help(
                     "canonicalize by following every symlink in every component of the \
                      given name recursively, without requirements on components existence",
-                ),
+                )
+                .action(ArgAction::SetTrue),
         )
         .arg(
             Arg::new(OPT_RELATIVE_TO)
                 .long(OPT_RELATIVE_TO)
-                .takes_value(true)
                 .value_name("DIR")
                 .value_parser(NonEmptyStringValueParser::new())
                 .help("print the resolved path relative to DIR"),
@@ -156,14 +161,13 @@ pub fn uu_app<'a>() -> Command<'a> {
         .arg(
             Arg::new(OPT_RELATIVE_BASE)
                 .long(OPT_RELATIVE_BASE)
-                .takes_value(true)
                 .value_name("DIR")
                 .value_parser(NonEmptyStringValueParser::new())
                 .help("print absolute paths unless paths below DIR"),
         )
         .arg(
             Arg::new(ARG_FILES)
-                .multiple_occurrences(true)
+                .action(ArgAction::Append)
                 .required(true)
                 .value_parser(NonEmptyStringValueParser::new())
                 .value_hint(clap::ValueHint::AnyPath),
@@ -244,19 +248,18 @@ fn canonicalize_relative(
 /// symbolic links.
 fn resolve_path(
     p: &Path,
-    zero: bool,
+    line_ending: LineEnding,
     resolve: ResolveMode,
     can_mode: MissingHandling,
     relative_to: Option<&Path>,
     relative_base: Option<&Path>,
 ) -> std::io::Result<()> {
     let abs = canonicalize(p, can_mode, resolve)?;
-    let line_ending = if zero { b'\0' } else { b'\n' };
 
     let abs = process_relative(abs, relative_base, relative_to);
 
-    print_verbatim(&abs)?;
-    stdout().write_all(&[line_ending])?;
+    print_verbatim(abs)?;
+    stdout().write_all(&[line_ending.into()])?;
     Ok(())
 }
 
