@@ -1,23 +1,21 @@
-//  * This file is part of the uutils coreutils package.
-//  *
-//  * (c) KokaKiwi <kokakiwi@kokakiwi.net>
-//  * (c) Jian Zeng <anonymousknight86@gmail.com>
-//  *
-//  * For the full copyright and license information, please view the LICENSE
-//  * file that was distributed with this source code.
+// This file is part of the uutils coreutils package.
+//
+// For the full copyright and license information, please view the LICENSE
+// file that was distributed with this source code.
 
 // spell-checker:ignore (paths) wtmp
 
 use std::ffi::OsString;
 use std::path::Path;
 
+use clap::builder::ValueParser;
 use clap::{crate_version, Arg, Command};
 use uucore::error::UResult;
-use uucore::format_usage;
 use uucore::utmpx::{self, Utmpx};
+use uucore::{format_usage, help_about, help_usage};
 
-static ABOUT: &str = "Print the user names of users currently logged in to the current host";
-const USAGE: &str = "{} [FILE]";
+const ABOUT: &str = help_about!("users.md");
+const USAGE: &str = help_usage!("users.md");
 
 static ARG_FILES: &str = "files";
 
@@ -31,19 +29,19 @@ If FILE is not specified, use {}.  /var/log/wtmp as FILE is common.",
 
 #[uucore::main]
 pub fn uumain(args: impl uucore::Args) -> UResult<()> {
-    let after_help = get_long_usage();
-
-    let matches = uu_app().after_help(&after_help[..]).get_matches_from(args);
+    let matches = uu_app()
+        .after_help(get_long_usage())
+        .try_get_matches_from(args)?;
 
     let files: Vec<&Path> = matches
         .get_many::<OsString>(ARG_FILES)
         .map(|v| v.map(AsRef::as_ref).collect())
         .unwrap_or_default();
 
-    let filename = if !files.is_empty() {
-        files[0]
-    } else {
+    let filename = if files.is_empty() {
         utmpx::DEFAULT_FILE.as_ref()
+    } else {
+        files[0]
     };
 
     let mut users = Utmpx::iter_all_records_from(filename)
@@ -59,7 +57,7 @@ pub fn uumain(args: impl uucore::Args) -> UResult<()> {
     Ok(())
 }
 
-pub fn uu_app<'a>() -> Command<'a> {
+pub fn uu_app() -> Command {
     Command::new(uucore::util_name())
         .version(crate_version!())
         .about(ABOUT)
@@ -67,8 +65,8 @@ pub fn uu_app<'a>() -> Command<'a> {
         .infer_long_args(true)
         .arg(
             Arg::new(ARG_FILES)
-                .takes_value(true)
-                .max_values(1)
-                .value_hint(clap::ValueHint::FilePath),
+                .num_args(1)
+                .value_hint(clap::ValueHint::FilePath)
+                .value_parser(ValueParser::os_string()),
         )
 }
