@@ -1,4 +1,5 @@
 #!/bin/sh
+# spell-checker:ignore uuhelp
 ARG=""
 if test "$1" != "--do-it"; then
     ARG="--dry-run --allow-dirty"
@@ -35,7 +36,7 @@ TOTAL_ORDER=$(echo -e $PARTIAL_ORDER | tsort | tac)
 TOTAL_ORDER=${TOTAL_ORDER#ROOT}
 
 set -e
-for dir in src/uucore_procs/ src/uucore/ src/uu/stdbuf/src/libstdbuf/; do
+for dir in src/uuhelp_parser/ src/uucore_procs/ src/uucore/ src/uu/stdbuf/src/libstdbuf/; do
     (
         cd "$dir"
         #shellcheck disable=SC2086
